# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- ...

## [1.0.1] - 2021-02-28

### Fixed
- Fix cut flow reports with `recursive=True` argument
- Fix in SLURM batch backend: `NODE_FAIL` status should be interpreted as a failed job 
- Fix running `bambooRun` with `--onlyprepare`

## [1.0.0] - 2021-12-13

This is the first stable release of bamboo, after quite some time of active
development and use in several analyses.
Having releases and meaningful version numbers should make it easier
to keep track of changes between versions, and to coordinate development.
